==> spongeapi-8.0.0-20210211.013413-350-sources.jar: org/spongepowered/api/data/persistence/DataSerializable.java <==
/*
 * This file is part of SpongeAPI, licensed under the MIT License (MIT).
 *
 * Copyright (c) SpongePowered <https://www.spongepowered.org>
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.spongepowered.api.data.persistence;

/**
 * Represents an object that can be represented by a {@link DataContainer}.
 * <p>DataContainers received from {@link DataSerializable#toContainer()}
 * should be considered to be copies of the original data, and therefore,
 * thread safe.</p>
 */
public interface DataSerializable {

    /**
     * Gets the content version of this {@link DataSerializable}. The version
     * may differ between instances of plugins and implementations such that
     * the {@link DataView} from {@link #toContainer()} may include different
     * information, or remove other information as they are no longer deemed
     * necessary. The version goes hand in hand with {@link DataContentUpdater}
     * as it is required when there exists any {@link DataView} of this
     * {@link DataSerializable} with an "older" version.
     *
     * @return The version of the content being serialized
     */
    int getContentVersion();

    /**
     * Serializes this object into a comprehensible {@link DataContainer}.
     *
     * @return A newly created DataContainer
     */
    DataContainer toContainer();

}

==> spongeapi-8.0.0-20220108.065912-540-sources.jar: org/spongepowered/api/data/persistence/DataSerializable.java <==
/*
 * This file is part of SpongeAPI, licensed under the MIT License (MIT).
 *
 * Copyright (c) SpongePowered <https://www.spongepowered.org>
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.spongepowered.api.data.persistence;

/**
 * Represents an object that can be represented by a {@link DataContainer}.
 * <p>DataContainers received from {@link DataSerializable#toContainer()}
 * should be considered to be copies of the original data, and therefore,
 * thread safe.</p>
 */
public interface DataSerializable {

    /**
     * Gets the content version of this {@link DataSerializable}. The version
     * may differ between instances of plugins and implementations such that
     * the {@link DataView} from {@link #toContainer()} may include different
     * information, or remove other information as they are no longer deemed
     * necessary. The version goes hand in hand with {@link DataContentUpdater}
     * as it is required when there exists any {@link DataView} of this
     * {@link DataSerializable} with an "older" version.
     *
     * @return The version of the content being serialized
     */
    int contentVersion();

    /**
     * Serializes this object into a comprehensible {@link DataContainer}.
     *
     * @return A newly created DataContainer
     */
    DataContainer toContainer();

}
